% scias.cls
%
% class file for ScienceAsia articles
%
% author: Michael A. Allen, Physics Department, Mahidol University, Thailand
% email: maa5652 at gmail dot com
%
% Copyright 2008, 2009, 2010, 2011, 2012, 2013
% Michael A. Allen <frmaa at mahidol dot ac dot th>
%
% This file may be distributed and/or modified under the conditions of the
% LaTeX Project Public License, either version 1.3 of this licence, or
% any later version. The latest version of this license is at
% http://www.latex-project.org/lppl.txt and version 1.3 is part
% of all distributions of LaTeX version 2003/06/01 or later.
%
% Any modified versions of this file must be renamed with new filenames
% distinct from scias.cls

% options: 
% [submit] - no doi or logo; line numbers; head: Submitted to ScienceAsia
% [ref] - as above; msnumber 1st page (if available)
% [onecolumn] - only available with submit, reference, and doc options
% [edit] - doi page: ???; head centre: ms no, #pages; page-range xxx-xxx
% [proof] - same as edit but with linenumbers and watermark
% [nowm] - no watermark with proof option
% [issue] - exactly as in issue (so no hyperlinks)
% [html] - for producing html version via tex4ht
% [nolineno] - force no line numbers (e.g. in submit/ref/proof)
% [lineno] - force line numbers (e.g. in doc)
% [doc] - ScienceAsia documentation

% todo:
% bug: first citation in article cannot be \refcite - fails with full issue
% add \phantom{p} to end of address to ensure even spacing
% can't handle DOIs including #
% table label bug with [issue] e.g. 08-0166 - position of tlabel?
% fix bug: writes wrong first page number if last page completely full
% look at http://www.ams.org/authors/author-faq.html
% effects of hypcap on spacing
% effects of length of keywords on front matter spacing (08-0049)
% problem with tnote - it affects positioning in column
% line numbers too low so mess up \FrontMatterExtraVskip
% linenumbers seem to affect layout - e.g. 08-0058
% add DblFloatExtraVskip
% anchor for definition of abbreviation: use \hypertarget{name}{text}
%   and  \hyperlink{name}{text}  
% restore default penalties at start (in case changed in previous document)
% comments from editor to author via line number labels
% \nccsection  - no case change section

% misc notes:
% use  pdffonts filename.pdf  to check embedded fonts

% warning: lineno can upset alignment of bottom of columns
% warning: soul interferes a bit with positions of line numbers
% warning: need to delete aux files if using hyperrefs for first time

\NeedsTeXFormat{LaTeX2e}
% note: date must be padded with zeros!
%\ProvidesClass{scias}[2008/12/09 v0.19 ScienceAsia article class]
%\ProvidesClass{scias}[2009/02/04 v0.191 ScienceAsia article class]
%\ProvidesClass{scias}[2009/02/05 v0.192 ScienceAsia article class]
%\ProvidesClass{scias}[2009/02/09 v0.193 ScienceAsia article class]
%\ProvidesClass{scias}[2009/03/18 v0.195 ScienceAsia article class]
%\ProvidesClass{scias}[2009/04/13 v0.2 ScienceAsia article class]
%\ProvidesClass{scias}[2009/06/18 v0.21 ScienceAsia article class]
%\ProvidesClass{scias}[2010/02/02 v0.22 ScienceAsia article class]
%\ProvidesClass{scias}[2010/06/21 v0.23 ScienceAsia article class]
%\ProvidesClass{scias}[2010/09/21 v0.24 ScienceAsia article class]
%\ProvidesClass{scias}[2012/04/01 v0.25 ScienceAsia article class]
\ProvidesClass{scias}[2012/12/30 v0.26 ScienceAsia article class]
\LoadClass[twocolumn,twoside]{article}
% for other possible fonts see
% http://www.tug.dk/FontCatalogue/mathfonts.html
\RequirePackage{times} % gives times but no change to stuff in mathmode
%\RequirePackage{pslatex} % gives all as times new roman including mathmode
% problems with pslatex: no conversion of maths to bf in headings
%\usepackage[charter]{mathdesign}
%\RequirePackage{charter} % looks strange (t's too short)
%\RequirePackage{fouriernc} % New Century Schoolbook
\RequirePackage{amsmath}
%\RequirePackage{amsthm} % needed for \theoremstyle
% but puts dot after Theorem 1. 
% also look at the ntheorem package - meant to be good for proof environment
\RequirePackage{amssymb}
\RequirePackage{upgreek}
\RequirePackage{ogonek} % for Polish accent e.g. \k{e}
\RequirePackage{url} % needs to be v3.3 or later
%\RequirePackage{indentfirst} % indents paragraph following heading
%\RequirePackage{float}
% subfig seems to cause text in 2nd column to overwrite table*
%\RequirePackage{subfig} % for subfigures and subtables
\RequirePackage{ndblfloatfix} % single and double column floats appear
                             % in order and allows double column
                             % floats to appear at the bottom of a page 
                             % - but package has a bug - ordinary floats can
                             % appear in the wrong order if pos not given!!
\RequirePackage{twoopt}
\RequirePackage{fancyhdr}
\RequirePackage{graphicx}
\RequirePackage{listings} % for program listings (lstlisting)
\RequirePackage{longtable}
\RequirePackage{threeparttable} % for tables with notes
\RequirePackage{booktabs} % for improved tables
\RequirePackage[version=3]{mhchem} % for chemical formulae/equations
\RequirePackage{soul} % needed for \? (breakable underlining/highlighting)
\RequirePackage{color} % needed for watermark
\RequirePackage{textcomp} % for \textdegree, etc
\RequirePackage{ifthen}
\RequirePackage{rotating} % for rotating text (in table headings)
% cannot use verbatim for full issue
%\RequirePackage{verbatim} % for \begin{comment} \end{comment}
%\RequirePackage[title]{appendix}

\newif\if@no@options \@no@optionstrue
\newif\if@submit
\newif\if@referee
\newif\if@proof
%\newif\if@no@wm 
\newif\if@lineno
\newif\if@one@column
\newif\if@edit
\newif\if@doc
\newif\if@submitORdoc
\newif\if@issue
\newif\if@html
\newif\if@displaymsn \@displaymsntrue
\DeclareOption{edit}{\@edittrue \@no@optionsfalse}
\DeclareOption{proof}{\@prooftrue \@linenotrue \@no@optionsfalse}
\DeclareOption{submit}{\@submittrue \@submitORdoctrue \@linenotrue \@displaymsnfalse \@no@optionsfalse}
\DeclareOption{ref}{\@refereetrue \@submittrue \@linenotrue \@no@optionsfalse}
\DeclareOption{doc}{\@doctrue \@submitORdoctrue  \@displaymsnfalse \@linenofalse \@no@optionsfalse}
\DeclareOption{onecolumn}{\@one@columntrue}
\DeclareOption{issue}{\@issuetrue}
\DeclareOption{html}{\@htmltrue}
\DeclareOption{nolineno}{\@linenofalse}
\DeclareOption{lineno}{\@linenotrue}
%\DeclareOption{nowm}{\@no@wmtrue}
\ProcessOptions
\if@submitORdoc % cancel proof and edit options if submit or ref present
\@prooffalse \@editfalse
\else \@one@columnfalse \fi % cancel onecolumn option if not submit

% must run latex 2 or 3 times (and maybe delete aux files first) for lineno
% to work properly - also see
% phaseportrait.blogspot.com/2007/08/lineno-and-amsmath-compatibility.html
\if@lineno 
\usepackage[\if@one@column\else switch,\fi displaymath,mathlines]{lineno}
  % set font for line numbers
  %\renewcommand{\linenumberfont}{\sffamily\fontsize{7pt}{7pt}\selectfont}
  %\renewcommand{\linenumberfont}{\sffamily\fontsize{6pt}{7pt}\selectfont}
\renewcommand{\linenumberfont}{\normalfont\scriptsize\sffamily}
  % set distance of linenumbers from text
\setlength{\linenumbersep}{20pt}
\linenumbers
\fi
\newif\if@hrefs

\ifx\@sciasissue\undefined
\else
\@issuetrue
\fi

\if@issue\else
%\if@no@wm
%\if@proof\else
%\if@submit\else
%\if@lineno\else
% only load hyperref if no line numbers and not complete issue
\definecolor{PageUrlColour}{rgb}{0,0,0.5} % medium blue
\definecolor{LinkColour}{rgb}{0,0,0.3} % dark blue
\definecolor{orange}{rgb}{1,0.65,0} % orange
% link colours need to be dark otherwise not clear when printed in b&w
\RequirePackage[colorlinks,citecolor=LinkColour,
linkcolor=LinkColour,urlcolor=black,
bookmarks=false]{hyperref}
\def\figureautorefname{Fig.}
\def\lemmaautorefname{Lemma}
\def\corollaryautorefname{Corollary}
\def\propositionautorefname{Proposition}
\def\identityautorefname{Identity}
\def\@remarkautorefname{Remark}
\def\@definitionautorefname{Definition}
\def\@exampleautorefname{Example}
\def\@algorithmautorefname{Algorithm}
\@hrefstrue
% improves links to environments (redefined env must not be in options)
% but gives problems with space below caption
\RequirePackage[figure*]{hypcap}
\renewcommand{\hypcapspace}{0pt} % link points above env by this amount  
%\fi % end of \if@lineno
%\fi % end of \if@submit\else
%\fi % end of \if@proof\else
%\fi % end of \if@no@wm
\fi % end of \ifx\@sciasissue\undefined

% add leading zeros (from zahl2string.sty)
\newcommand{\@fillzeros}[1]{%
\ifcase%
\ifnum\number#1<10 1%
\else\ifnum\number#1<100 2%
\else3%
\fi\fi %
\or00#1% 
\or0#1%
\or#1%
\or%
\fi%
}

% 3-letter abbreviation of today's month
\newcommand{\monthIII}{%
\ifcase\month
\or Jan\or Feb\or Mar\or Apr\or May\or Jun%
\or Jul\or Aug\or Sep\or Oct\or Nov\or Dec\fi}

\RequirePackage[super,sort&compress,comma]{natbib}
\setcitestyle{citesep={,\,}}
%\usepackage{hypernat}

\newcommand{\noftx}[1]{#1} % for use with fixtex

% science asia article link
\newcommand{\saal}[1]{\hypersetup{urlcolor=PageUrlColour}\href{http://dx.doi.org/10.2306/scienceasia1513-1874.\@pubyear.\@volume.\@fillzeros{#1}}{#1}\hypersetup{urlcolor=black}}

% bibitem hyperlink
\if@no@options % final version no coloured links for bibitems
\newcommand{\bihl}[2]{\href{http://dx.doi.org/#1}{#2}}
%\newcommand{\bihehl}[2]{\href{http://dx.doi.org/#1##}{#2}}
\else % coloured links
% swap meaning of % and # and the swap back
%\catcode`\%=6 \catcode`\#=12 
\newcommand{\bihl}[2]{\hypersetup{urlcolor=LinkColour}\href{http://dx.doi.org/#1}{#2}\hypersetup{urlcolor=black}}
%\catcode`\%=12 \catcode`\#=6
%\newcommand{\bihehl}[2]{\hypersetup{urlcolor=LinkColour}\href{http://dx.doi.org/#1##}{#2}\hypersetup{urlcolor=black}}
\fi

\if@hrefs\else
\newcommand{\hypersetup}[1]{\relax}
\newcommand{\href}[2]{#2}
\renewcommand{\saal}[1]{#1}
\newcommand{\capstart}{\relax}
% to avoid problems with aux file
\fi

\hypersetup{pdfcreator=\if@submit{scias.cls}\else{ScienceAsia}\fi}
\if@doc
\def\@simplehead{\href{http://www.scienceasia.org/}{\textit{ScienceAsia}}
  documentation: \href{http://www.scienceasia.org/scias_\@filestem.pdf}
{scias\_\@filestem.pdf}}
\else
\def\@simplehead{Submitted to \href{http://www.scienceasia.org/}{\textit{ScienceAsia}}}
\fi

%\RequirePackage[numbers,sort&compress]{natbib}
% nocompress option needed since sometimes have hyperlinks
%\RequirePackage[superscript,nomove,ref,nocompress]{cite} % needs recent version
%\renewcommand\citeleft{}\renewcommand\citeright{}\renewcommand\citemid{}
% use \refcite as bibunits doesn't know \citen
% the glue ~ doesn't seem to work
%\newcommand{\refcite}[1]{\in@{,}{#1}Ref\ifin@ s\fi.~\citenum{#1}}
\newcommand{\refcite}[1]{\in@{,}{#1}Ref\ifin@ s\fi\@.{\upshape\citenum{#1}}}
%\newcommandtwoopt{\citep}[3][][]{%
%\ifthenelse{\equal{#1#2}{}}{\cite{#3}}% no optional arguments
%{\ifthenelse{\equal{#1}{}}{(\refcite{#3}, #2)}% 1st opt arg empty 
%{\ifthenelse{\equal{#2}{}}{(#1 \refcite{#3})}% 2nd opt arg empty
%{(#1 \refcite{#3}, #2)}}}% both opt args present
%}
%\newcommand{\citet}[1]{\refcite{#1}}
%% make citations superscripts, taken from citesupernumber.sty
%\def\@cite#1#2{$^{\mbox{\scriptsize #1\if@tempswa , #2\fi}}$}
%\def\@cite#1#2{$^{\mbox{\it\scriptsize #1\if@tempswa , #2\fi}}$}
%\RequirePackage{hypernat}

\newcounter{@issuecount}
\newcommand{\issnum}[1]{\def\@issnum{#1}\setcounter{@issuecount}{\@issnum}}

\newcommand{\ArticleType}[1]{\def\@arttype{#1}}
\ArticleType{ResearchArticle} % default
\newcounter{@yrcount}
\newcommand{\msnumber}[1]{\def\@msnumber{#1}}
\newcommand{\filestem}[1]{\def\@filestem{#1}}
\newcommand{\volume}[1]{\def\@volume{#1}
\ifthenelse{\equal{\@volume}{0}}{\def\@volume{??}\def\@pubyear{20??}}%
{\setcounter{@yrcount}{\@volume}
\addtocounter{@yrcount}{1974}\def\@pubyear{\arabic{@yrcount}}}
\def\@volheadtxt{{\em ScienceAsia} \@volume\ (\@pubyear)}
\ifthenelse{\equal{\@volume}{0}}{\def\@volhead{\@volheadtxt}}
{\def\@volhead{\href{http://www.scienceasia.org/\@pubyear.html}{\@volheadtxt}}}
} % end of volume definition
\newcommand{\firstpage}[1]{\def\@firstpgno{#1}}
% seems that TeX can't write files beginning with . (but can read them)
\newcommand{\@vnatfile}{zzvnat.tex} % name of file with volume num and art type
\newcommand{\@fpgnof}{zzfpn.tex} % name of file with first page number
\newcommand{\@lpgnof}{zzlpn.tex} % name of file with last page number
\IfFileExists{\@vnatfile}{\input{\@vnatfile}}{\volume{0}}
\def\@firstpgno{1} % default first page number
\def\@lastpgno{1} % default last page number
\if@no@options 
  \@displaymsnfalse
  \IfFileExists{\@fpgnof}{% first page file present 
    \newread\@filenum
    \openin\@filenum=\@fpgnof
    \read\@filenum to\@firstpgno
    \closein\@filenum}{}
  \IfFileExists{\@lpgnof}{% last page file present 
    \newread\@filenum
    \openin\@filenum=\@lpgnof
    \read\@filenum to\@lastpgno
    \closein\@filenum}{}
\fi

% query for author
\sethlcolor{yellow} % colour of highlight
\newcommand{\?}[1]{#1} % default: do nothing 
\if@edit\renewcommand{\?}[1]{\hl{#1}}\fi
\if@proof\renewcommand{\?}[1]{\hl{#1}}\fi
% needs fixing by editors before sending out
\newcommand{\fix}[1]{\sethlcolor{red}\hl{#1}\sethlcolor{yellow}}
\newcommand{\qomit}[1]{\sethlcolor{orange}\hl{[[#1 -- omit this?]]}\sethlcolor{yellow}}

%\if@proof\if@no@wm\else % watermark on every page
% taken from draftwatermark.sty v1.0 and everypage.sty v1.1
% by Sergio Callegari
%\fi\fi

\renewcommand\textfraction{.0} % minimum fraction of a page that has text
\setcounter{totalnumber}{9} % max number of floats on one page
\renewcommand{\dbltopfraction}{.999} % top fraction of page that can be
                                % taken up with *floats (was .85)
\renewcommand{\dblfloatpagefraction}{.9} % minimum fraction of float
% page that must be taken up by *floats - high value stops floats
% appearing on their own
\renewcommand{\topfraction}{1} % top fraction of page that can be
                                % taken up with floats (was .85)
\renewcommand{\floatpagefraction}{.999} % minimum fraction of float
% page that must be taken up by floats - high value stops floats
% appearing on their own
\renewcommand{\bottomfraction}{.999}


% have different definitions in sciasissue.cls
\newcommand{\auidx}[1]{}
\newcommand{\kwidx}[1]{}
\newcommand{\ikwidx}[1]{}

% needed for inside bibliography environment
\newif\ifnoatproof
\if@proof
\noatprooftrue
\def\auidxes{}
\renewcommand{\auidx}[1]{%
\ifthenelse{\equal{\protect\auidxes}{}}
{\def\auidxes{#1}}
{\g@addto@macro\auidxes{\\ {#1}}} 
}
\else\noatprooffalse
\fi

%\newcounter{@fpage} % first page of article (used by sciasissue.cls)
\newcounter{@nauthors} % number of authors
\newcounter{@ncauthors} % number of corresponding authors

\textwidth 156mm
%\textheight 222mm % old value
\textheight 222.9mm % size chosen so that col of unbroken text fits exactly
\voffset 0mm
\topmargin 0mm
%\headheight 10pt
%\headsep 10mm
\headheight 8mm
\headsep 5mm
%\footskip 10mm % old value
\footskip 9.1mm % adjusted to keep \textheight+\footskip the same as before
\if@issue
\oddsidemargin 3.65mm % 1cm+7/8in-1in -1/8in
\evensidemargin -2.7mm % 1cm+1/2in-1in 
\else
\oddsidemargin 1mm % mean of above two is 0.475mm
\evensidemargin 1mm
\fi
\columnsep 0.1875in             %   Space between columns
\setlength{\parindent}{6mm} % size of paragraph indentation
\parskip=0pt % plus1pt % no flexible space between paragraphs
%\setlength\parskip{0pt plus 0pt minus 0pt}
% lengths used in frontmatter
\newlength{\adsslength}
\setlength{\adsslength}{3mm}
\newlength{\adlength}
\setlength{\adlength}{\textwidth}
\addtolength{\adlength}{-\adsslength}
\newlength{\adqflength}
\setlength{\adqflength}{-1.5mm}
\setlength{\adqflength}{0mm}
\newlength{\datesindent}
\setlength{\datesindent}{\textwidth}
\addtolength{\datesindent}{-32mm}
\renewcommand{\headrulewidth}{0pt}
\newlength{\frontmatterextravskip} % front matter total vskip correction 
\newlength{\fmvskipcor} % front matter vskip correction

\renewcommand{\baselinestretch}{1.0}
\setcounter{secnumdepth}{0}
\setcounter{@nauthors}{0}
\setcounter{@ncauthors}{0}

\def\@authors{}
\def\@plainauthors{} % list of authors without superscripts
\renewcommand{\author}[2][]{\addtocounter{@nauthors}{1}
\in@{*}{#1}\ifin@\addtocounter{@ncauthors}{1}\fi
\ifthenelse{\equal{\@authors}{}}{\def\@authors{#2\adss{#1}}
\def\@plainauthors{#2}}
{\g@addto@macro\@authors{, \mbox{#2\adss{#1}}}
\g@addto@macro\@plainauthors{, #2}}
} % end of \author definition

\newcommand{\@addr@layout}[2]{\ifthenelse{\equal{#1}{}}{#2}%
{\if@html
{\Large\normalfont\textsuperscript{#1~}}#2
\else
\makebox[\adsslength][l]{$^{{\rm #1}}$}%
\parbox[t]{\adlength}{\raggedright#2}%
\fi}
%\vspace{\adqflength}
}

% \protect needed otherwise get "Argument of \equal has an extra }" error
\def\@addresses{}
\newcommand{\address}[2][]{%
\ifthenelse{\equal{\protect\@addresses}{}}
{\def\@addresses{\@addr@layout{#1}{#2}}}
{\g@addto@macro\@addresses{\\ \@addr@layout{#1}{#2}}} 
}

\def\@eads{} % e-mail addresses
\DeclareUrlCommand\email{\urlstyle{rm}}
\newcommand{\ead}[1]{
\ifthenelse{\equal{#1}{}}{}% ignored if argument empty
{%\in@{@}{#1}\ifin@\relax\typeout{*** no @ in e-mail address #1 ***}\fi
\in@{_}{#1}\ifin@ % underscore in e-mail address (gives problems with href)
\ifthenelse{\equal{\@eads}{}}{\urldef\@eads\email{#1}}
{\g@addto@macro\@eads{, \protect\email{#1}}}
\else % no underscore in e-mail address
\ifthenelse{\equal{\@eads}{}}{\def\@eads{\href{mailto:#1}{#1}}}
{\g@addto@macro\@eads{, \href{mailto:#1}{#1}}}
\fi}
} % end of \ead definition



\renewcommand{\abstract}[1]{\def\@abstract{#1}}
\newcommand{\keywords}[1]{\def\@keywords{#1}}
\keywords{} % default
\if@html
\newcommand{\adss}[1]{{\Large\normalfont\textsuperscript{#1}}}
\else
\newcommand{\adss}[1]{$^{{\rm #1}}$}
\fi
%\newcommand{\adss}[1]{$^{\text{#1}}$}
\newcommand{\dates}[2]{\def\@received{#1}\def\@accepted{#2}}

%% FONTS
% {9pt}{11pt}: if sep less than 11pt \'E gives uneven linespacing
\newcommand{\@doifont}{\fontsize{10pt}{10pt}\selectfont} % doi
\newcommand{\@absfont}{\fontsize{9pt}{11pt}\selectfont} % abstract/keywords
\newcommand{\@capfont}{\fontsize{9pt}{11pt}\selectfont} % caption
\newcommand{\@ackfont}{\fontsize{9pt}{11.146pt}\selectfont} % acknowledgements
%\newcommand{\reffont}{\fontsize{11pt}{11pt}\selectfont} % references
\newcommand{\reffont}{\fontsize{9pt}{11.146pt}\selectfont} % references
\newcommand{\htmlreffont}{\fontsize{11pt}{9pt}\selectfont} % references
% 11.146 ensures ref only column is same height as standard height

\newcommand{\smaller}{\fontsize{8pt}{8pt}\selectfont} % for use in tables 
\newcommand{\evensmaller}{\fontsize{7pt}{7pt}\selectfont} % for use in tables 

\newcommand{\@saurl}{{\fontsize{7pt}{7pt}\selectfont \url{www.scienceasia.org}}}

% use smaller font for verbatim
\def\verbatim@font{%
  \normalfont \ttfamily\smaller
  \catcode`\<=\active
  \catcode`\>=\active
}

\msnumber{}
\dates{???}{???}

\newcommand{\@blklnk}[1]{\hypersetup{linkcolor=black}#1%
\hypersetup{linkcolor=LinkColour}}

\newcommand{\@headcentre}{
\if@displaymsn
\fancyhead[C]{{\@absfont\sffamily \@msnumber\
\if@submit\else(\@blklnk{\pageref{lastpage}} pages)\fi}}
\fi
}

\if@submitORdoc\else
    \def\@doipre{10.2306/scienceasia1513-1874.\@pubyear.\@volume.}
\fi

\fancypagestyle{plain}{% redefine plain page style
  \fancyhf{} % clear header and footer fields
  \if@submitORdoc\fancyhead[L]{\@simplehead}
  \else
    \if@displaymsn\else
    \def\@doifull{\@doipre\@fillzeros{\thepage}}
    \hypersetup{pdftitle=doi:\@doifull}
    \fi
    \fancyhead[L]{\raisebox{-1.8ex}{\parbox{8cm}{\incgcm{4}{\@arttype}
          \vskip-1ex{\@doifont doi: \if@displaymsn\@doipre???\else%
\href{http://dx.doi.org/\@doifull}{\@doifull}\fi}}}}
  \fi
  \if@displaymsn\@headcentre\fi
  \if@submitORdoc\fancyhead[R]{{\thepage}}\else
%    \fancyhead[R]{{\@absfont {\em ScienceAsia} \@volume\ (\@pubyear): 
    \fancyhead[R]{{\@absfont \@volhead: 
    \if@displaymsn {\bf xxx}-{\bf xxx} 
    \else{\bf \thepage\/}--{\bf \@blklnk{\pageref{lastpage}}}\fi}}
  \fi
  \fancyfoot[LE,RO]{\@saurl}
}

\fancypagestyle{normal}{% define normal page style for articles/indices
\fancyhead{}
\fancyhead[LE,RO]{{\thepage}}
\if@submitORdoc
  \fancyhead[RE,LO]{{\@absfont \@simplehead}}
\else
%  \fancyhead[RE,LO]{{\@absfont {\em ScienceAsia} \@volume\ (\@pubyear)}}
  \fancyhead[RE,LO]{{\@absfont \@volhead}}
  \@headcentre
\fi
\fancyfoot{}
\fancyfoot[LE,RO]{\@saurl}
}

% needed to balance right column on front page if it doesn't contain
% any stretchable/shrinkable vertical space
\newcommand{\FrontMatterExtraVskip}[1]{
\setlength{\frontmatterextravskip}{#1}
\setlength{\fmvskipcor}{0.2\frontmatterextravskip}
}
\FrontMatterExtraVskip{0pt} % default

\newcounter{@firstpgnocount}
\newcommand{\firstpgnocopy}{\setcounter{@firstpgnocount}{\@firstpgno}}
\newcounter{@lastpgnocount}
\newcommand{\lastpgnocopy}{\setcounter{@lastpgnocount}{\@lastpgno}}

\def\@frontmattertext{%
% if html version has title, authors, abstract then move next two
% lines to end of this definition and remove else 
% table of contents at start of html version (without title Contents)
\if@html\renewcommand{\contentsname}{}\tableofcontents\else
\if@html
% seems to be necessary otherwise .pdf is lost
\firstpgnocopy
\lastpgnocopy
\def\@pdffile{http://www.scienceasia.org/\@pubyear.\@volume.n\@issnum/scias\@volume_\arabic{@firstpgnocount}.pdf}
\def\@doifull{\@doipre\@fillzeros{\@firstpgno}}
\newcommand{\doifullagain}{\@doifull}
\fi % tex4ht ignores pgsty
\thispagestyle{plain}
\suppressfloats[t] % stop floats appearing at top of this page
%  \let \footnote \thanks
\if@html
\href{http://www.scienceasia.org/}{\textit{ScienceAsia}}
\ifcase\@issnum\or March\or June\or September\or December\fi~\@pubyear\
\href{http://www.scienceasia.org/\@pubyear.html}{Volume~\@volume}
\href{http://www.scienceasia.org/content/content.php?v=\@volume&i=\@issnum&y=\@pubyear}{Number~\@issnum}
\href{http://dx.doi.org/\@doifull}{\arabic{@firstpgnocount}--\arabic{@lastpgnocount}}
% below \ar.. needed (instead of \@doifull) to avoid extra space -- seems to be
% caused by extra space in \@firstpgno due to it being read from a file
doi:~\href{http://dx.doi.org/\@doifull}{\@doipre\@fillzeros{\arabic{@firstpgnocount}}}
\mbox{~}
[\href{\@pdffile}{PDF file}]
\\
{\sc
\ifthenelse{\equal{\@arttype}{InvitedEditorial}}{Invited editorial}{}
\ifthenelse{\equal{\@arttype}{OpinionArticle}}{Opinion article}{}
\ifthenelse{\equal{\@arttype}{ReviewArticle}}{Review article}{}
\ifthenelse{\equal{\@arttype}{ResearchArticle}}{Research article}{}
\ifthenelse{\equal{\@arttype}{ShortReport}}{Short report}{}
}\mbox{}\\
\fi
{\raggedright\if@html\fontsize{18}{18}\else\fontsize{18}{21}\fi\selectfont
\fontseries\bfdefault\selectfont\boldmath % ensures maths is bold too
%\bfseries
\vskip 7pt
\@title \if@doc\\ {\small [this~version:~\number\day~\monthIII~\number\year; 
for the latest version see \href{http://www.scienceasia.org/scias_\@filestem.pdf}{www.scienceasia.org/scias\_\@filestem.pdf}]}\fi 
\if@html\\\mbox{}\fi \par}%
    \vskip 9pt%
\noindent
%\if@referee{\sf AUTHOR DETAILS OMITTED}\else
    {\normalsize\sloppy
      \lineskip 3pt% does this control distance between parboxes?
\raggedright
\if@html\mbox{}\\\fi
{\bfseries \@authors} \par \vskip 6pt
\raggedright
\noindent\@addresses\if@html\\\mbox{}\fi
      \par \vskip 1em
}
\hypersetup{pdfauthor=\@plainauthors}
\noindent
\ifthenelse{\equal{\arabic{@nauthors}}{1}}{}%
{\if@html{\Large\textsuperscript{*~}}\else$^{*}$\fi Corresponding author\ifthenelse{\arabic{@ncauthors}>1}{s}{}, }%
e-mail: \ifthenelse{\equal{\@eads}{}}{???}{\@eads}
%\fi % end of \if@referee
%\vskip 1em%
\if@html\\\mbox{}\\\mbox{}\fi\par
\if@submitORdoc\else
\ifthenelse{\equal{\@arttype}{OpinionArticle}\or%
\equal{\@arttype}{InvitedEditorial}}{}{%
\vskip\fmvskipcor
{\if@html\@absfont\fi
{\em \hfill Received~~\@received\if@html~~~~\fi\par 
\hfill Accepted~~\@accepted\if@html\\\mbox{}\\\mbox{}\fi\par}}}
\fi % end of \if@submitORdoc
\vskip 1em \vskip\fmvskipcor
\noindent {\if@html\else\@absfont\fi  {\bfseries ABSTRACT}: \@abstract}\par
\ifthenelse{\equal{\@keywords}{}}{}{%
\vskip 1em \vskip\fmvskipcor
\if@html\mbox{}\\\mbox{}\\\mbox{}\fi\noindent 
{\if@html\else\@absfont\fi {\bfseries KEYWORDS}: \@keywords}}
\vskip 2em  \vskip\fmvskipcor \vskip\fmvskipcor
\hypersetup{pdftitle=\@title,pdfkeywords=\@keywords}
\fi % end of \if@html
} % end of def frontmattertext

\newcommand{\frontmatter}{%
\if@one@column\onecolumn\@frontmattertext\if@doc\tableofcontents\fi\else\newpage
\twocolumn[\begin{@twocolumnfalse}\@frontmattertext
\end{@twocolumnfalse}]\if@doc\tableofcontents\fi\fi
\FrontMatterExtraVskip{0pt} % reset to zero
%\addtocounter{@AN}{1}
\setcounter{equation}{0} % reset equation, figure and table numbers
\setcounter{figure}{0}
\setcounter{table}{0}
\setcounter{theorem}{0}
\setcounter{lemma}{0}
\setcounter{corollary}{0}
\setcounter{proposition}{0}
\setcounter{identity}{0}
\setcounter{@remark}{0}
\setcounter{@definition}{0}
\setcounter{@example}{0}
\setcounter{@algorithm}{0}
\if@doc\else
\addtocontents{toc}{\protect\item[\thepage]\@title\\{\small\em \@authors}}
\fi
\pagestyle{normal} % default pagestyle
\setcounter{@nauthors}{0}
\setcounter{@ncauthors}{0}
\gdef\@authors{} % empty \@authors (must be \gdef as used \g@addto@macro)
\gdef\@addresses{} % empty \@addresses
\gdef\@auidxes{}
\gdef\@eads{} % empty \@eads
\ifx\@morethanoneart\undefined % (defined in sciasissue.cls)
\setcounter{page}{\@firstpgno}
\fi
\ifx\@sciasissue\undefined\else
\@addtoindices % (defined in sciasissue.cls)
\setcounter{@fpage}{\thepage} % (used by sciasissue.cls)
\fi
} % end of frontmatter definition

\def\@maketitle{% % keep in case author insists on using maketitle
                % % rather than frontmatter
\if@one@column\onecolumn\else\newpage\fi
\@frontmattertext
\pagestyle{normal}
}

% following taken from textcase.sty with extra `%' added to prevent
% extraneous space at start of output from \MakeTextUppercase
\def\@uclcnotmath#1#2#3#4{\begingroup
      #1%
      \def\({$}\let\)\(%$
      \def\NoCaseChange##1{\noexpand\NoCaseChange{\noexpand##1}}%
      \@nonchangecase\label%
      \@nonchangecase\ref%
      \@nonchangecase\ensuremath%
      \def\cite##1##{\toks@{\noexpand\cite##1}\@citex}%
      \def\@citex##1{\NoCaseChange{\the\toks@{##1}}}%
      \def\reserved@a##1##2{\let#2\reserved@a}%
      \expandafter\reserved@a\@uclclist\reserved@b{\reserved@b\@gobble}%
      \protected@edef\reserved@a{\endgroup%
          \noexpand\@skipmath#3#4$\valign$}%
      \reserved@a}%
\def\@nonchangecase#1{\def#1##1{\NoCaseChange{#1{##1}}}}%
\let\NoCaseChange\@firstofone%
\def\@skipmath#1#2$#3${%
  \@skip@nonchangecase#1#2\NoCaseChange\valign%
  \ifx\valign#3%
  \else%
    $#3$%
    \expandafter\@skipmath\expandafter#1%
  \fi}%
\def\@skip@nonchangecase#1#2\NoCaseChange#3{%
  #1{#2}%
  \ifx\valign#3%
  \else
    #3%
    \expandafter\@skip@nonchangecase\expandafter#1%
  \fi}
\DeclareRobustCommand\MakeTextUppercase{%
\@uclcnotmath{\def\i{I}\def\j{J}}{##1##2}\uppercase}
\protected@edef\MakeTextUppercase#1{\MakeTextUppercase{#1}}

% section headings do not have line numbers because of \MakeTextUppercase
\renewcommand\thesection{}
% number after \@plus is the stretchability
% number after \@minus is the shrinkability
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-1.5ex \@plus -1.5ex \@minus -.2ex}%
   %{-2.5ex \@plus -0ex \@minus -.2ex}% original vspace above heading 
                                   %{-2.5ex \@plus -.2ex \@minus -.2ex}%
                                   {1ex \@plus.2ex}%
         %{1.3ex \@plus.2ex}% original vspace below heading
{\raggedright\normalfont\normalsize\fontseries\bfdefault\selectfont\boldmath%
\MakeTextUppercase}}
%        {\normalfont\normalsize\bfseries\MakeTextUppercase}}
%                          {\normalfont\normalsize\protect\bfseries}}

\renewcommand\thesubsection{}
% note - can sometimes have problems with lack of stretchability below heading
\renewcommand\subsection{\@startsection {subsection}{2}{\z@}%
                                   {-1.5ex \@plus -1.5ex \@minus -.2ex}%
                           %{-2.5ex \@plus -0ex \@minus -.2ex}% original
                                   {1ex}%
                          %    {1.3ex \@plus.2ex}% original
{\raggedright\normalfont\normalsize\fontseries\bfdefault\selectfont\boldmath}}
%                                   {\normalfont\normalsize\bfseries}}

\newcommand\osubsection{\@startsection {subsection}{2}{\z@}%
                                   {-1.5ex \@plus -1.5ex \@minus -.2ex}%
                           %{-2.5ex \@plus -0ex \@minus -.2ex}% original
                                   {1ex \@plus.5ex}%
                          %    {1.3ex \@plus.2ex}% original
{\raggedright\normalfont\normalsize\fontseries\bfdefault\selectfont\boldmath}}
%                                   {\normalfont\normalsize\bfseries}}

\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                    {1.5ex \@plus1ex \@minus.2ex}%
                                    {-1em}%
                                    {\normalfont\normalsize\itshape}}



\renewcommand\thefigure{\@arabic\c@figure}
\renewcommand\thetable{\@arabic\c@table}
\renewcommand{\figurename}{Fig.}

% For making issue and individual articles look the same:
% sometimes needed for figures and tables 
% and even for ordinary text (see end of 2008-0078)
% typical difference is 1.9
% conditional vertical space: 2nd arg is for issue
\newcommand{\CondVSkip}[2]{
\if@issue \vspace*{#2 pt} \else \vspace*{#1 pt} \fi
}

%\setlength\@dblfptop{4pt}
%\setlength\@dblfpsep{4pt}
 % sep above \toprule (booktabs.sty) 
% \abovetopsep is space between caption and toprule
\if@hrefs\setlength\abovetopsep{3.1pt}\fi % to compensate for effect of hypcap
%\if@hrefs\setlength\abovetopsep{4pt}\fi % to compensate for effect of hypcap
% above is original
%\setlength\belowbottomsep{2pt} % sep below \bottomrule (booktabs.sty)

% same value so that don't need to use \topcaption (which temp swaps them)
\setlength\abovecaptionskip{4\p@}
%\setlength\belowcaptionskip{4\p@} % this should not be set to a fixed length 
% - otherwise get unwanted gap below caption for [b] figures
%\setlength\belowcaptionskip{0\p@}
\setlength\floatsep{15pt \@plus 40pt \@minus 5pt} % space left between floats.
%\setlength\dblfloatsep{10pt} % for 2 col output
%\setlength\textfloatsep{5pt} % space between last top float or 
                           % first bottom float and the text
%\setlength\dbltextfloatsep{5pt} % for 2 col output

\setlength{\tabcolsep}{3\p@} % default: 6\p@

% format for figure and table captions
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  {\@capfont {\bfseries #1}~~#2}\par
  \vskip\belowcaptionskip
}

% captions for long tables
\def\LT@makecaption#1#2#3{%
  \LT@mcol\LT@cols c{\hbox to\z@{\hss\parbox[t]\textwidth{%
    \sbox\@tempboxa{{\bfseries #1{#2}}~~#3}%
    \ifdim\wd\@tempboxa>\hsize
      {\@capfont {\bfseries #1{#2}}~~#3}%
    \else
      \hbox to\hsize{\hfil\box\@tempboxa\hfil}%
    \fi
    \endgraf\vskip\baselineskip}%
  \hss}}}

% format for longtable captions
%\long\def\LT@makecaption#1#2{%
%  \vskip\abovecaptionskip
%  {\@capfont {\bfseries #1}~~#2}\par
%  \vskip\belowcaptionskip
%}

% redefine figure environment to add extra space at top
\let\oldfigure\figure
\let\endoldfigure\endfigure
\renewenvironment{figure}[1][tbp]%
{\begin{oldfigure}[#1]\vspace*{4pt}\capstart}{\end{oldfigure}}


% redefine tnote (threeparttable.sty) so that it doesn't upset alignment
\let\oldtnote\tnote
\renewcommand{\tnote}[1]{\makebox[0pt][l]{\oldtnote{#1}}}
%\def\tnote#1{\protect\TPToverlap{{\normalsize\textsuperscript{\TPTtagStyle{#1}}}}}% 
%\def\tnote#1{\TPToverlap{{\normalsize\textsuperscript{\TPTtagStyle{#1}}}}}% 
%\def\tnote#1{\normalsize\textsuperscript{#1}}% 
% add font specification to tablenotes environment (threeparttable.sty)
\let\oldtablenotes\tablenotes
\let\endoldtablenotes\endtablenotes
\renewenvironment{tablenotes}%
{\begin{oldtablenotes}\@capfont}{\end{oldtablenotes}}

% redefine table and table* environments to include threeparttable
\let\oldtable\table
\let\endoldtable\endtable
\renewenvironment{table}[1][tbp]%
{\begin{oldtable}[#1]\capstart
\begin{threeparttable}\@capfont}
{\normalsize\end{threeparttable}\end{oldtable}}

\expandafter\let\csname oldtablestar\expandafter\endcsname\csname table*\endcsname
\expandafter\let\csname oldendtablestar\expandafter\endcsname\csname endtable*\endcsname
\renewenvironment{table*}[1][tbp]%
{\oldtablestar[#1]\capstart\begin{threeparttable}\@capfont}
{\normalsize\end{threeparttable}\oldendtablestar}
%For aligning numbers in tables to the dot (or the \tpm)
\newcommand{\phD}{\phantom{0}}		%one "phantom" digit
\newcommand{\phDD}{\phantom{00}} 	%two digits
\newcommand{\phDDD}{\phantom{000}} 	%three digits
\newcommand{\phPD}{\phantom{.0}}		%point digit
\newcommand{\phPDD}{\phantom{.00}}	%point two digits
\newcommand{\phN}{\phantom{\tnote{a}}}	%one note
\newcommand{\phNN}{\phantom{\tnote{aa}}}	%two notes
\newcommand{\phNNN}{\phantom{\tnote{aaa}}}	%three notes
\newcommand{\phM}{\phantom{\ensuremath{-}}}	%minus
\newcommand{\phS}{\phantom{$^*$}}	%star


\newcommand{\acknowledgements}[1]
{\ifthenelse{\equal{#1}{}}{\relax}{
%\if@referee\section{{\sf Acknowledgements omitted}}\else%
\paragraph{Acknowledgements\normalfont:}{\@ackfont \if@html ~\else\fi#1}%\fi
}}

\let \acknowledgments \acknowledgements % to allow for US spelling of it


\newcommand{\hyphenations}[1]{\hyphenation{#1}\hyphenation{#1s}}
% \hyphenation{}
\hyphenations{exu-date}
\hyphenation{gal-acto-glu-co-man-nans}
\hyphenation{gal-acto-man-nans}
\hyphenation{glu-co-man-nans}
\hyphenation{man-na-no-hydro-lase}
\hyphenation{multi-dim}
\hyphenation{multi-dimen-sional}
\hyphenation{re-issued}
\hyphenations{waste-water}

\newcommand{\wbr}{\hskip0pt plus0.6pt\relax} %word break
\newcommand{\fh}{\wbr-\wbr} %flexible hyphen


% note: To suggest hyphenation points for strings containing nonletters or accented letters, use the \- command in the input text. 

\newcommand{\dash}{-\hspace{0cm}}
\newcommand{\edash}{\if@html\else-\fi} % emergency/extra dash

% redefine \ce (mhchem.sty) so that case doesn't change
\let\oldce\ce
\def\ce#1{\NoCaseChange{\oldce{#1}}}

%% start of MACROS for ScienceAsia

%% environments 
\newtheorem{theorem}{Theorem}
\newtheorem{thm}[theorem]{Theorem}
\newtheorem{lemma}{Lemma}
\newtheorem{lem}[lemma]{Lemma}
\newtheorem{corollary}{Corollary}
\newtheorem{cor}[corollary]{Corollary}
\newtheorem{proposition}{Proposition}
\newtheorem{prop}[proposition]{Proposition}
\newtheorem{identity}{Identity}
\newtheorem{idn}[identity]{Identity}
\newtheorem{@remark}{Remark}
\newenvironment{remark}{\begin{@remark}\upshape}{\end{@remark}}
\newenvironment{rem}{\begin{@remark}\upshape}{\end{@remark}}
\newtheorem{@definition}{Definition}
\newenvironment{definition}{\begin{@definition}\upshape}{\end{@definition}}
\newenvironment{defn}{\begin{@definition}\upshape}{\end{@definition}}
\newtheorem{@example}{Example}
\newenvironment{example}{\begin{@example}\upshape}{\end{@example}}
%\newenvironment{exmpl}{\begin{@example}\upshape}{\end{@example}}
\newtheorem{@algorithm}{Algorithm}
\newenvironment{algorithm}{\begin{@algorithm}\upshape}{\end{@algorithm}}
\newenvironment{alg}{\begin{@algorithm}\upshape}{\end{@algorithm}}
\newenvironment{proof}[1][]%
{\noindent\textit{\ifthenelse{\equal{#1}{}}{Proof}{Proof #1}}: }%
{\leavevmode\unskip\nobreak\quad\hspace*{\fill}$\Box$\par}
% might be better to omit the \nobreak in the above
% -- it tries to force box not to be on a line on its own
%    which sometimes results in ugly hyphenation

% must have leftmarg=labsep+labwidth-itemindent
\newcounter{@step}\newcounter{@substep}
\newcommand{\setfirststepnumber}[1]
{\setcounter{@step}{#1}\addtocounter{@step}{-1}}
\newenvironment{steps}{\begin{list}{Step~\arabic{@step}:}
{\setlength{\labelwidth}{-2mm}\setlength{\leftmargin}{6mm}
\setlength{\labelsep}{2mm}\setlength{\itemindent}{-6mm}
\setlength{\listparindent}{6mm}
\setlength{\topsep}{0pt}\setlength{\itemsep}{0ex}\setlength{\parsep}{0ex}
\usecounter{@step}}}
{\end{list}}

% redefine enumerate (intended for use in theorem-like environments only)
\newcounter{@enum}
\renewcommand{\the@enum}{\roman{@enum}}
\renewenvironment{enumerate}{\begin{list}{{\upshape(\the@enum)}}
{\setlength{\labelwidth}{-2mm}\setlength{\leftmargin}{6mm}
\setlength{\labelsep}{2mm}\setlength{\itemindent}{-6mm}
\setlength{\listparindent}{6mm}
\setlength{\topsep}{0pt}\setlength{\itemsep}{0ex}\setlength{\parsep}{0ex}
\usecounter{@enum}}}
{\end{list}}

%% lstlisting settings - 'numberfirstline=false' is ignored??
\lstset{xleftmargin=8pt,
  numberfirstline=false,framerule=0pt,
  numbers=left,numberstyle=\tiny,stepnumber=5,numbersep=4pt,
  basicstyle=\small\ttfamily,commentstyle=\rmfamily,stringstyle=\textsl,
  language={}}

%% hyperlinked abbreviations
\newcommand{\newabb}[2]{\hypertarget{#2}{#1 (#2)}}
\newcommand{\abb}[1]{\hyperlink{#1}{#1}}

%% hyperlinked items
\if@issue
\newcommand{\hlitem}[2]{\item[{\rm#2}]}
\newcommand{\refhli}[2]{{\rm#2}}
\else
\newcommand{\hlitem}[2]{\hypertarget{#1}{\item[{\rm#2}]}}
\newcommand{\refhli}[2]{\hyperlink{#1}{{\rm#2}}}
\fi

%% formatting
\newcommand{\bc}{\begin{center}}
\newcommand{\ec}{\end{center}}
\newcommand{\bde}{\begin{description}}
\newcommand{\ede}{\end{description}}

%% figures
\newcommand{\iL}{\textit{left}}
\newcommand{\iR}{\textit{right}}
\newcommand{\iT}{\textit{top}}
\newcommand{\iM}{\mbox{\textit{middle}}}
\newcommand{\iB}{\mbox{\textit{bottom}}}
\newcommand{\bfig}{\begin{figure}}
\newcommand{\efig}{\end{figure}}
\newcommand{\bfigs}{\begin{figure*}}
\newcommand{\efigs}{\end{figure*}}
\newcommand{\incgcm}[2]{%\IfFileExists{}
\includegraphics[width=#1cm]{#2}
} %
\newcommand{\incgcmh}[2]{\includegraphics[height=#1cm]{#2}} %
\newcommand{\cincgcm}[2]{\centering{\includegraphics[width=#1cm]{#2}}} %
\newcommand{\cincgrcm}[2]{\centering{\includegraphics[angle=-90,width=#1cm]{#2}}} %
\newcommand{\incgcw}[1]{\includegraphics[width=\if@html16cm\else\columnwidth\fi]{#1}} %
\newcommand{\incglcw}[1]{\includegraphics[angle=90,width=\if@html16cm\else\columnwidth\fi]{#1}} % rotate included graphics
\newcommand{\incgrcw}[1]{\includegraphics[angle=-90,width=\if@html16cm\else\columnwidth\fi]{#1}} % rotate included graphics
\newcommand{\incgtw}[1]{\includegraphics[width=\textwidth]{#1}} %
\newcommand{\incghcw}[1]{\includegraphics[width=0.485\columnwidth]{#1}} %
\newcommand{\incgtcw}[1]{\includegraphics[width=0.33\columnwidth]{#1}} %
\newcommand{\incgcmhII}[3]{\incgcmh{#1}{#2} \incgcmh{#1}{#3}}
\newcommand{\incgcmhIII}[4]{\incgcmh{#1}{#2} \incgcmh{#1}{#3} \incgcmh{#1}{#4}}
\newcommand{\incgcmhIV}[5]{\incgcmh{#1}{#2} \incgcmh{#1}{#3} \incgcmh{#1}{#4} \incgcmh{#1}{#5}}
% include low resolution versions of figures if not issue
\newcommand{\incgcwLR}[1]{\if@issue
\includegraphics[width=\columnwidth]{#1}%
\else\includegraphics[width=\columnwidth]{#1LR.jpg}\fi}
\newcommand{\incghcwLR}[1]{\if@issue\incghcw{#1}\else\incghcw{#1LR.jpg}\fi}
\newcommand{\incgcmhIILR}[3]{\if@issue\incgcmhII{#1}{#2}{#3}%
\else\incgcmhII{#1}{#2LR.jpg}{#3LR.jpg}\fi}
\newcommand{\incgcmhIIILR}[4]{\if@issue\incgcmhIII{#1}{#2}{#3}{#4}%
\else\incgcmhIII{#1}{#2LR.jpg}{#3LR.jpg}{#4LR.jpg}\fi}

%% tables
\newcommand{\btab}{\begin{table}}
\newcommand{\etab}{\end{table}}
\newcommand{\btabs}{\begin{table*}}
\newcommand{\etabs}{\end{table*}}
\newcommand{\btsf}[1]
{\begin{tabular*}{\linewidth}{@{\extracolsep{\fill}}#1}\toprule}
\newcommand{\etsf}{\bottomrule\end{tabular*}}
\newcommand{\btn}{\begin{tablenotes}}
\newcommand{\etn}{\end{tablenotes}}

%% equations
\newcommand{\beq}{\begin{equation}}
\newcommand{\eeq}{\end{equation}}
\newcommand{\bse}{\begin{subequations}}
\newcommand{\ese}{\end{subequations}}
\newcommand{\beqa}{\begin{eqnarray}}
\newcommand{\eeqa}{\end{eqnarray}}
\newcommand{\beqas}{\begin{eqnarray*}}
\newcommand{\eeqas}{\end{eqnarray*}}
\def\bml#1\eml{\begin{multline}#1\end{multline}} % suggested in technote.tex
\def\bmls#1\emls{\begin{multline*}#1\end{multline*}}
\def\bal#1\eal{\begin{align}#1\end{align}} % suggested in technote.tex
\def\bals#1\eals{\begin{align*}#1\end{align*}}
\def\bga#1\ega{\begin{gather}#1\end{gather}} % suggested in technote.tex
\def\bgas#1\egas{\begin{gather*}#1\end{gather*}}
\newcommand{\bsp}{\begin{split}}
\newcommand{\esp}{\end{split}}
\newcommand{\bald}{\begin{aligned}}
\newcommand{\eald}{\end{aligned}}
\newlength{\defaultmultlinegap}
\setlength{\defaultmultlinegap}{\multlinegap}
\newcommand{\zmlg}{\setlength{\multlinegap}{0pt}} % zero multlinegap
\newcommand{\rmlg}{\setlength{\multlinegap}{\defaultmultlinegap}} % restore

%% item environments
\newcommand{\bit}{\begin{itemize}}
\newcommand{\eit}{\end{itemize}}

%% labels and references
\newcommand{\elabel}[1]{\label{e:#1}}
\newcommand{\flabel}[1]{\label{f:#1}}
\newcommand{\tlabel}[1]{\label{t:#1}}
\newcommand{\llabel}[1]{\label{l:#1}}
\newcommand{\Tlabel}[1]{\label{T:#1}}
\newcommand{\Llabel}[1]{\label{L:#1}}
\newcommand{\Clabel}[1]{\label{C:#1}}
\newcommand{\Plabel}[1]{\label{P:#1}}
\newcommand{\Ilabel}[1]{\label{I:#1}}
\newcommand{\Rlabel}[1]{\label{R:#1}}
\newcommand{\Dlabel}[1]{\label{D:#1}}
\newcommand{\Elabel}[1]{\label{E:#1}}
\newcommand{\Alabel}[1]{\label{A:#1}}
\newcommand{\eref}[1]{\textup{(\ref{e:#1})}}
\newcommand{\eiref}[1]{\textup{(\ref{i:#1})}}
\newcommand{\fref}[1]{\if@hrefs\mbox{\autoref{f:#1}}\else\mbox{\figurename~\ref{f:#1}}\fi}
\newcommand{\tref}[1]{\if@hrefs\mbox{\autoref{t:#1}}\else\mbox{\tablename~\ref{t:#1}}\fi}
\newcommand{\lref}[1]{\if@hrefs\mbox{\autoref{l:#1}}\else\mbox{\lstlistingname~\ref{l:#1}}\fi}
\newcommand{\Tref}[1]{\if@hrefs\autoref{T:#1}\else Theorem~\ref{T:#1}\fi}
\newcommand{\Lref}[1]{\if@hrefs\autoref{L:#1}\else Lemma~\ref{L:#1}\fi}
\newcommand{\Cref}[1]{\if@hrefs\autoref{C:#1}\else Corollary~\ref{C:#1}\fi}
\newcommand{\Pref}[1]{\if@hrefs\autoref{P:#1}\else Proposition~\ref{P:#1}\fi}
\newcommand{\Iref}[1]{\if@hrefs\autoref{I:#1}\else Identity~\ref{I:#1}\fi}
\newcommand{\Rref}[1]{\if@hrefs\autoref{R:#1}\else Remark~\ref{R:#1}\fi}
\newcommand{\Dref}[1]{\if@hrefs\autoref{D:#1}\else Definition~\ref{D:#1}\fi}
\newcommand{\Eref}[1]{\if@hrefs\autoref{E:#1}\else Example~\ref{E:#1}\fi}
\newcommand{\Aref}[1]{\if@hrefs\autoref{A:#1}\else Algorithm~\ref{A:#1}\fi}

%% fractions
\newcommand{\sfrac}[2]{\mbox{$\frac{#1}{#2}$}} % use tfrac instead (amsmath)
\newcommand{\dsfrac}[2]{\frac{\displaystyle{#1}}{\displaystyle{#2}}} 
\newcommand{\pfrac}[3]{\left(\frac{#1}{#2}\right)^{#3}}

%vectors and matrices
\newcommand{\vect}[1]{\boldsymbol{\bf #1}} % need both bf and boldsymbol
\newcommand{\uvect}[1]{\boldsymbol{\bf \hat{#1}}} % unit vector
\newcommand{\spdot}{\,\vect{.}\,}  % scalar product dot
\newcommand{\grad}{\vect{\nabla}}
\renewcommand{\div}{\grad\spdot}
\newcommand{\curl}{\grad\times}

%% differentials and derivatives
\newcommand{\sod}[1]{\,\mathrm{d}#1} % space ordinary differential
\newcommand{\od}[1]{\mathrm{d}#1} % ordinary differential
\newcommand{\fod}[2]{\frac{\mathrm{d} #1}{\mathrm{d} #2}}
\newcommand{\fodn}[3]{\frac{\mathrm{d}^{#3} #1}{\mathrm{d} #2^{#3}}}
\newcommand{\pd}{\partial} % partial differential
\newcommand{\fpd}[2]{\frac{\partial #1}{\partial #2}}
\newcommand{\fpdn}[3]{\frac{\partial^{#3} #1}{\partial #2^{#3}}}

%% roman superscripts and subscripts
\providecommand{\textsubscript}[1]{$_\text{#1}$}
\newcommand{\rs}[1]{_{\mathrm{#1}}} % roman subscript
\newcommand{\rp}[1]{^{\mathrm{#1}}} % roman superscript (p for power)

%% degrees
% (the orginal definition is for an operator 'deg' used for degree of a
%  polynomial - this is rarely used and so has been replaced by Deg)
%\renewcommand{\deg}{\ensuremath{^{\circ}}}
\renewcommand{\deg}{\textdegree}
\newcommand{\Deg}{\operatorname{deg}}

\newcommand{\micro}{\textmu}
\newcommand{\mug}{\textmu g} % micrograms
\newcommand{\mul}{\textmu l} % microlitres
\newcommand{\mum}{\textmu m} % micrometres
\newcommand{\mumol}{\textmu mol} % micromoles
\newcommand{\muM}{\textmu M} % micromolar

%% sets
\newcommand{\Rset}{\mathbb{R}}
\newcommand{\Qset}{\mathbb{Q}}
\newcommand{\Zset}{\mathbb{Z}}
\newcommand{\Nset}{\mathbb{N}}
\newcommand{\Znset}{\mathbb{Z}\sb{n}} % \sb instead of _ so it's ok with tex4ht
\newcommand{\Cset}{\mathbb{C}}
% for backward compatibility:
\newcommand{\bbR}{\mathbb{R}}
\newcommand{\bbQ}{\mathbb{Q}}
\newcommand{\bbZ}{\mathbb{Z}}
\newcommand{\bbN}{\mathbb{N}}
\newcommand{\bbZn}{\mathbb{Z}\sb{n}} % \sb instead of _ so it is ok with tex4ht
\newcommand{\bbC}{\mathbb{C}}


%% integrals, limits, brackets
\newcommand{\intinfs}{\int_{-\infty}^\infty\!\!\!}

% generic left right delimiters
% #1=size (0=unspecified) #2=left delim #3=right delim #4=contents
\newcommand{\glrdelim}[4]
%{\ifcase#1\left\or\or\bigl\or\Bigl\or\biggl\or\Biggl\fi#2#4%
%\ifcase#1\right\or\or\bigr\or\Bigr\or\biggr\or\Biggr\fi#3}
% above doesn't work maybe because \bigl etc must be next to ( etc
{\ifcase#1\left#2\or#2\or\bigl#2\or\Bigl#2\or\biggl#2\or\Biggl#2\fi%
#4\ifcase#1\right#3\or#3\or\bigr#3\or\Bigr#3\or\biggr#3\or\Biggr#3\fi}

\newcommand{\av}[2][0]{\glrdelim{#1}{\langle}{\rangle}{#2}}
\newcommand{\sav}[1]{\langle#1\rangle}
\newcommand{\lrp}[2][0]{\glrdelim{#1}{(}{)}{#2}} % left-right parentheses 
\newcommand{\lrs}[2][0]{\glrdelim{#1}{[}{]}{#2}} % left-right square brackets
\newcommand{\lrb}[2][0]{\glrdelim{#1}{\{}{\}}{#2}} % left-right braces
\newcommand{\lrm}[2][0]{\glrdelim{#1}{\lvert}{\rvert}{#2}} % left-right mod 
\newcommand{\lrn}[2][0]{\glrdelim{#1}{\lVert}{\rVert}{#2}} % left-right norm 

%% functions and constants
% hspace in \e definition is needed to get spacing right after next -
\newcommand{\e}{\operatorname{e}\hspace{-0.15em}} % base of natural logarithms
\newcommand{\ii}{\mathrm{i}} % imaginary i 
%\newcommand{\degC}{$\,^\circ$C} % degrees C
\newcommand{\degC}{\,\textdegree C} % degrees C e.g. 37\degC
\newcommand{\nsdegC}{\textdegree C} % no space degrees C e.g. (\nsdegC)
\newcommand{\tpm}{$\,\pm\,$} % text plus or minus
\newcommand{\stpm}{$\pm\,$} % text plus or minus
\newcommand{\tlt}{$<$} % text less than
\newcommand{\ttimes}{$\,\times\,$} % text times
%\newcommand{\ttimes}{\,\texttimes\,} % text times
\newcommand{\sttimes}{$\times\,$} % single text times
%\newcommand{\sttimes}{\texttimes\,} % single text times
%\newcommand{\tpm}{\,\textpm\,} % \textpm looks strange 
\newcommand{\EXP}[1]{\ttimes10$^{#1}$}
\newcommand{\ccom}{\kern-0.3ex,\kern-0.3ex} % chemical comma
                                % e.g. $N\ccom N'$-diphenylthiourea
\providecommand{\operatorname}[1]{\mathop{\mathrm{#1}}\nolimits}
\newcommand{\Res}{\operatorname{Res}} % residue
\renewcommand{\Re}{\operatorname{Re}} % real part
\renewcommand{\Im}{\operatorname{Im}} % imaginary part 
\newcommand{\Arg}{\operatorname{Arg}} % principal argument
\newcommand{\Log}{\operatorname{Log}} % principal log
\newcommand{\Ln}{\operatorname{Ln}} % principal log
\newcommand{\sgn}{\operatorname{sgn}} % sign
\newcommand{\sech}{\operatorname{sech}}
\newcommand{\cosech}{\operatorname{cosech}}
\newcommand{\cosec}{\operatorname{cosec}}
\newcommand{\sinc}{\operatorname{sinc}} % sinc(x) = sin(x) / x 
\newcommand{\erf}{\operatorname{erf}} % error function
\newcommand{\erfc}{\operatorname{erfc}} % complementary error function
\newcommand{\tr}{\operatorname{tr}} % trace
\newcommand{\diag}{\operatorname{diag}}
\newcommand{\rank}{\operatorname{rank}}
\newcommand{\Det}{\operatorname{Det}} % determinant (\det is preferable)
\newcommand{\Var}{\mathrm{Var}}
\newcommand{\Cov}{\mathrm{Cov}}

%% arrays an matrices
\newcommand{\bfa}{\left\{\begin{array}} % piecewise function \bfa{cc}
\newcommand{\efa}{\end{array}\right.}
\newcommand{\bpm}{\begin{pmatrix}} % matrix
\newcommand{\epm}{\end{pmatrix}}
\newcommand{\bvm}{\begin{vmatrix}} % determinant
\newcommand{\evm}{\end{vmatrix}}

%% relations 
\renewcommand{\ll}{\!<\!\!<\!} % much less than
\renewcommand{\gg}{\!>\!\!>\!} % much greater than
\ifx\leqslant\undefined
\else
  \renewcommand{\leq}{\leqslant}
  \renewcommand{\geq}{\geqslant}
  \renewcommand{\le}{\leqslant}
  \renewcommand{\ge}{\geqslant}
\fi

%% norms
\newcommand{\abs}[1]{\left|#1\right|}
\newcommand{\norm}[2][]{\left\|#2\right\|_{#1}}
\newcommand{\snorm}[2][]{\|#2\|_{#1}}

%% words
\providecommand{\text}[1]{\mbox{#1}}
% below must have \textit{} not {\it } otherwise bf is not transferred
\newcommand{\SN}[1]{\NoCaseChange{\textit{#1}}} % scientific name
\newcommand{\prog}[1]{\textsc{#1}} % name of commercial software
\newcommand{\etal}{et~al}

\providecommand{\BibTeX}{\textsc{Bib}\kern-.08em\TeX}
\newcommand{\scias}{\mbox{\textit{ScienceAsia}}}

\newcommand{\ben}{\begin{enumerate}}
\newcommand{\een}{\end{enumerate}}
%% end of MACROS for ScienceAsia

\def\eqnarray{\stepcounter{equation}\let\@currentlabel\theequation
\global\@eqnswtrue
\global\@eqcnt\z@\tabskip\@centering\let\\\@eqncr
$$\halign to \displaywidth\bgroup\@eqnsel\hskip\@centering
  $\displaystyle\tabskip\z@{##}$&\global\@eqcnt\@ne
  \hfil${\;##\;}$\hfil
  &\global\@eqcnt\tw@ $\displaystyle\tabskip\z@{##}$\hfil 
   \tabskip\@centering&\llap{##}\tabskip\z@\cr}

\def\endeqnarray{%
      \@@eqncr
      \egroup
      \global\advance\c@equation\m@ne
   $$\global\@ignoretrue
}


\if@lineno
\newcommand*\patchAmsMathEnvironmentForLineno[1]{%
  \expandafter\let\csname old#1\expandafter\endcsname\csname #1\endcsname
  \expandafter\let\csname oldend#1\expandafter\endcsname\csname end#1\endcsname
  \renewenvironment{#1}%
     {\linenomath\csname old#1\endcsname}%
     {\csname oldend#1\endcsname\endlinenomath}}%
\newcommand*\patchBothAmsMathEnvironmentsForLineno[1]{%
  \patchAmsMathEnvironmentForLineno{#1}%
  \patchAmsMathEnvironmentForLineno{#1*}}%
% to get linenumbers to work in paragraph before eqnarray
\let\oldeqnarray\eqnarray
\let\endoldeqnarray\endeqnarray
\renewenvironment{eqnarray}%
{\begin{linenomath}\begin{oldeqnarray}}%
{\end{oldeqnarray}\end{linenomath}}
% to get linenumbers to work in paragraph before equation
%\let\oldequation\equation
%\let\endoldequation\endequation
%\renewenvironment{equation}%
%{\begin{linenomath*}\begin{oldequation}}%
%{\end{oldequation}\end{linenomath*}}
% to get linenumbers to work in paragraph before align
%\let\oldalign\align
%\let\endoldalign\endalign
%\renewenvironment{align}%
%{\linenomath\oldalign}%
%{\endoldalign\endlinenomath}
\patchBothAmsMathEnvironmentsForLineno{align}
\patchBothAmsMathEnvironmentsForLineno{multline}
\patchAmsMathEnvironmentForLineno{split}
\patchBothAmsMathEnvironmentsForLineno{gather}
\else % prevent .aux file unknown cntrl seq errors if lineno used last time 
\def\@LN#1#2{\relax}
\def\@LN@col#1{\relax}
\fi

\makeatletter % needed otherwise get \spacefactor errors
\renewcommand*{\@biblabel}[1]{\hfill#1.}
\makeatother

% standard state symbol (from p.104 symbols-a4.pdf 2009)
\makeatletter
\providecommand\barcirc{\mathpalette\@barred\circ}
\def\@barred#1#2{\ooalign{\hfil$#1-$\hfil\cr\hfil$#1#2$\hfil\cr}}
\newcommand\stst{^{\protect\barcirc}}
\makeatother

\renewcommand\refname{REFERENCES}

\let\oldthebibliography=\thebibliography
\let\endoldthebibliography=\endthebibliography
\renewenvironment{thebibliography}[1]{%
  \begin{oldthebibliography}{#1}%
%\if@html\typeout{**** reference  in HTML ***}
%\else\typeout{**** reference not in HTML ***}
%\fi
    \setlength{\parskip}{0ex}%
    \setlength{\itemsep}{0ex}%
\if@html\htmlreffont\else\reffont\fi
%\nonfrenchspacing % turn off frenchingspace 
}{\label{lastpage}
\end{oldthebibliography}
\ifnoatproof
\par\mbox{}\\ \scias\ annual author index entries:\auidxes
\fi
}
%\frenchspacing  % if present gives no extra space after end of sentence
%\def\nonfrenchspacing{\sfcode`\.3000 \sfcode`\?3000\sfcode`\!3000
%\sfcode`\:2000 \sfcode`\;1500 \sfcode`\,1250 }
%\def\nonfrenchspacing{\sfcode`\.2000 \sfcode`\?2000\sfcode`\!2000
%\sfcode`\:1600 \sfcode`\;1000 \sfcode`\,1000 }

%% Something in-between \frenchspacing and \nonfrenchspacing
\def\semifrenchspacing{\sfcode`\.2000\sfcode`\?2000\sfcode`\!2000%
    \sfcode`\:1500\sfcode`\;1250\sfcode`\,1125 }
%%

\bibliographystyle{scias}
\hyphenpenalty 1000
%\emergencystretch1em
%\tolerance2000
\urlstyle{rm}
